@@ -21,7 +21,7 @@ templateIcons = {
 def add_icon_to_text(text):
     for lable in templateIcons.keys():
         if text.lower().startswith(lable):
-            return (templateIcons[lable] + text.split(lable)[-1]).title()
+            return (templateIcons[lable] + text.split(lable)[-1])
     return text
 
 
